API Reference
=============

This section provides detailed documentation for the ExactCIs package API.

Core Module
-----------

.. automodule:: exactcis.core
   :members:
   :undoc-members:
   :show-inheritance:

Methods
-------

Blaker's Method
~~~~~~~~~~~~~~

.. automodule:: exactcis.methods.blaker
   :members:
   :undoc-members:
   :show-inheritance:

Conditional Method
~~~~~~~~~~~~~~~~

.. automodule:: exactcis.methods.conditional
   :members:
   :undoc-members:
   :show-inheritance:

Mid-P Method
~~~~~~~~~~~

.. automodule:: exactcis.methods.midp
   :members:
   :undoc-members:
   :show-inheritance:

Unconditional Method
~~~~~~~~~~~~~~~~~~

.. automodule:: exactcis.methods.unconditional
   :members:
   :undoc-members:
   :show-inheritance:

Wald Method
~~~~~~~~~~

.. automodule:: exactcis.methods.wald
   :members:
   :undoc-members:
   :show-inheritance:


Utils
-----

Statistics
~~~~~~~~~

.. automodule:: exactcis.utils.stats
   :members:
   :undoc-members:
   :show-inheritance:

Optimization
~~~~~~~~~~~

.. automodule:: exactcis.utils.optimization
   :members:
   :undoc-members:
   :show-inheritance:

Parallel Processing
~~~~~~~~~~~~~~~~~

.. automodule:: exactcis.utils.parallel
   :members:
   :undoc-members:
   :show-inheritance:

Command Line Interface
--------------------

.. automodule:: exactcis.cli
   :members:
   :undoc-members:
   :show-inheritance:
